Function parse_iter
Source pub fn parse_iter(text: &str) -> Result<ParseIter<'_>, Error>
Returns an iterator over instructions in the given text.
Unlike parse function, the returned iterator doesn’t error on
duplicate stage names.
Errors
When .next() on the returned iterator has returned an error, the behavior
of subsequent .next() calls is unspecified.